@@ -7,6 +7,7 @@ from waddle import ParamBunch
 from .db2i import Db2i
 from .db2i_native import Db2iNative
 from .hp3000 import Hp3000
+from .hp3000_odbc import Hp3000Odbc
 from .mssql import SqlServer
 from .mysql import Mysql
 from .netsuite import Netsuite
@@ -16,39 +17,20 @@ from .postgres import Postgres
 from .redshift import Redshift
 from .snowflake import Snowflake
 from .vertica import Vertica
+from .progress_openedge import ProgressOpenedge
 
 
 gtl = threading.local()
 log = logging.getLogger(__name__)
 
 
-
-class ConnectionManager:
-    thread_local_key = 'concentric_connection_manager'
-
-
+class Config:
     def __init__(self):
         self.conf = ParamBunch()
+        initialized = False
 
-    def add_config(self, *filenames):
-        for filename in filenames:
-            self.conf.from_file(filename, True)
-
-    @classmethod
-    def get_instance(cls, *filenames):
-        global gtl
-        manager = getattr(gtl, cls.thread_local_key, None)
-        if manager:
-            return manager
-        manager = cls()
-        manager.add_config(*filenames)
-        setattr(gtl, cls.thread_local_key, manager)
-        return manager
-
-    @classmethod
-    def get_connector(cls, alias):
-        manager = cls.get_instance()
-        conf = manager.conf[alias]
+    def get_connector(self, alias):
+        conf = self.conf[alias]
         if conf.engine == 'oracle':
             return conf, Oracle
         if conf.engine == 'oracledb':
@@ -59,6 +41,8 @@ class ConnectionManager:
             return conf, Db2iNative
         if conf.engine == 'hp3000':
             return conf, Hp3000
+        if conf.engine == 'hp3000_odbc':
+            return conf, Hp3000Odbc
         if conf.engine == 'mssql':
             return conf, SqlServer
         if conf.engine == 'mysql':
@@ -73,11 +57,33 @@ class ConnectionManager:
             return conf, Snowflake
         if conf.engine == 'vertica':
             return conf, Vertica
+        if conf.engine == 'progress_openedge':
+            return conf, ProgressOpenedge
         return None, None
 
+    def add_config(self, *filenames):
+        for filename in filenames:
+            self.conf.from_file(filename, True)
+        initialized = True
+
+
+config = Config()
+
+
+def setup_concentric(*filenames):
+    """
+    sets up concentric by initializing the config with the filenames passed in
+    """
+    global config
+    config.add_config(*filenames)
+
+
+class ConnectionManager:
+    thread_local_key = 'concentric_connection_manager'
+
     @classmethod
     def connect(cls, alias, ping=False):
-        conf, connector = cls.get_connector(alias)
+        conf, connector = config.get_connector(alias)
         return connector.connect(conf)
 
 
@@ -87,7 +93,7 @@ class CachingConnectionManager(ConnectionManager):
 
     @classmethod
     def test_connection(cls, alias, conn):
-        _, engine = cls.get_connector(alias)
+        _, engine = config.get_connector(alias)
         ping_query = getattr(engine, 'ping_query')
         if ping_query:
             try:
@@ -200,7 +206,7 @@ class Alchemist:
             conn = cls.connections.get(using)
             if conn and not force:
                 return conn
-            conf, connector = ConnectionManager.get_connector(using)
+            conf, connector = config.get_connector(using)
             url = connector.sql_alchemy_connection_string(conf)
             initial = initial or conf.get('initial') or []
             kwargs.setdefault('pool_pre_ping', True)
@@ -239,7 +245,7 @@ class Alchemist:
 
 
 def cleanup_cached_connections():
-    m = CachingConnectionManager.get_instance()
+    m = CachingConnectionManager
     m.cleanup()
 
 
